@@ -163,6 +163,11 @@ struct evdev_device {
 		struct matrix usermatrix; /* as supplied by the caller */
 
 		struct device_coords dimensions;
+
+		struct {
+			struct device_coords min, max;
+			struct ratelimit range_warn_limit;
+		} warning_range;
 	} abs;
 
 	struct {
@@ -299,6 +304,11 @@ struct fallback_dispatch {
 	struct {
 		struct device_coords point;
 		int32_t seat_slot;
+
+		struct {
+			struct device_coords min, max;
+			struct ratelimit range_warn_limit;
+		} warning_range;
 	} abs;
 
 	struct {
@@ -585,6 +595,33 @@ evdev_libinput_context(const struct evdev_device *device)
 	return device->base.seat->libinput;
 }
 
+/**
+ * Convert the pair of delta coordinates in device space to mm.
+ */
+static inline struct phys_coords
+evdev_device_unit_delta_to_mm(const struct evdev_device* device,
+			      const struct device_coords *units)
+{
+	struct phys_coords mm = { 0,  0 };
+	const struct input_absinfo *absx, *absy;
+
+	if (device->abs.absinfo_x == NULL ||
+	    device->abs.absinfo_y == NULL) {
+		log_bug_libinput(evdev_libinput_context(device),
+				 "%s: is not an abs device\n",
+				 device->devname);
+		return mm;
+	}
+
+	absx = device->abs.absinfo_x;
+	absy = device->abs.absinfo_y;
+
+	mm.x = 1.0 * units->x/absx->resolution;
+	mm.y = 1.0 * units->y/absy->resolution;
+
+	return mm;
+}
+
 /**
  * Convert the pair of coordinates in device space to mm. This takes the
  * axis min into account, i.e. a unit of min is equivalent to 0 mm.
@@ -640,4 +677,59 @@ evdev_device_mm_to_units(const struct evdev_device *device,
 
 	return units;
 }
+
+static inline void
+evdev_device_init_abs_range_warnings(struct evdev_device *device)
+{
+	const struct input_absinfo *x, *y;
+	int width, height;
+
+	x = device->abs.absinfo_x;
+	y = device->abs.absinfo_y;
+	width = device->abs.dimensions.x;
+	height = device->abs.dimensions.y;
+
+	device->abs.warning_range.min.x = x->minimum - 0.05 * width;
+	device->abs.warning_range.min.y = y->minimum - 0.05 * height;
+	device->abs.warning_range.max.x = x->maximum + 0.05 * width;
+	device->abs.warning_range.max.y = y->maximum + 0.05 * height;
+
+	/* One warning every 5 min is enough */
+	ratelimit_init(&device->abs.warning_range.range_warn_limit,
+		       s2us(3000),
+		       1);
+}
+
+static inline void
+evdev_device_check_abs_axis_range(struct evdev_device *device,
+				  unsigned int code,
+				  int value)
+{
+	int min, max;
+
+	switch(code) {
+	case ABS_X:
+	case ABS_MT_POSITION_X:
+		min = device->abs.warning_range.min.x;
+		max = device->abs.warning_range.max.x;
+		break;
+	case ABS_Y:
+	case ABS_MT_POSITION_Y:
+		min = device->abs.warning_range.min.y;
+		max = device->abs.warning_range.max.y;
+		break;
+	default:
+		return;
+	}
+
+	if (value < min || value > max) {
+		log_info_ratelimit(evdev_libinput_context(device),
+				   &device->abs.warning_range.range_warn_limit,
+				   "Axis %#x value %d is outside expected range [%d, %d]\n"
+				   "See %s/absolute_coordinate_ranges.html for details\n",
+				   code, value, min, max,
+				   HTTP_DOC_LINK);
+	}
+}
+
 #endif /* EVDEV_H */
